@@ -27,10 +27,7 @@ func (root *Root) toggleWrapMode(context.Context) {
 		root.setMessageLog(err.Error())
 		return
 	}
-	// Move if off screen
-	if x < m.x || x > m.x+(root.scr.vWidth-root.scr.startX) {
-		m.x = x
-	}
+	m.x = x
 	root.setMessagef("Set WrapMode %t", m.WrapMode)
 }
 
@@ -39,6 +36,7 @@ func (root *Root) toggleColumnMode(context.Context) {
 	root.Doc.ColumnMode = !root.Doc.ColumnMode
 
 	if root.Doc.ColumnMode {
+		root.prepareLines(root.scr.lines)
 		root.Doc.columnCursor = root.Doc.optimalCursor(root.scr, root.Doc.columnCursor)
 	}
 	root.setMessagef("Set ColumnMode %t", root.Doc.ColumnMode)
@@ -121,6 +119,19 @@ func (root *Root) toggleMouse(context.Context) {
 	}
 }
 
+func (root *Root) toggleRuler(ctx context.Context) {
+	switch root.Doc.general.RulerType {
+	case RulerNone:
+		root.Doc.general.RulerType = RulerRelative
+	case RulerRelative:
+		root.Doc.general.RulerType = RulerAbsolute
+	case RulerAbsolute:
+		root.Doc.general.RulerType = RulerNone
+	}
+	root.setMessagef("Set Ruler %s", root.Doc.RulerType.String())
+	root.ViewSync(ctx)
+}
+
 // closeFile requests the file to be closed.
 func (root *Root) closeFile(context.Context) {
 	if err := root.Doc.closeFile(); err != nil {
@@ -187,13 +198,13 @@ func (root *Root) watchControl() {
 func (root *Root) searchGo(ctx context.Context, lN int, searcher Searcher) {
 	root.resetSelect()
 	root.Doc.lastSearchLN = lN
-	x := root.searchXPos(lN, searcher)
+	start, end := root.searchXPos(lN, searcher)
 	if root.Doc.jumpTargetSection {
-		root.Doc.searchGoSection(ctx, lN, x)
+		root.Doc.searchGoSection(ctx, lN, start, end)
 		return
 	}
 	root.debugMessage(fmt.Sprintf("searchGo:%d->%d", root.Doc.topLN, lN))
-	root.Doc.searchGoTo(lN, x)
+	root.Doc.searchGoTo(lN, start, end)
 }
 
 // goLine will move to the specified line.
@@ -519,8 +530,8 @@ func (root *Root) esFormat(ctx context.Context) {
 // setDelimiter sets the delimiter string.
 func (root *Root) setDelimiter(input string) {
 	root.Doc.setDelimiter(input)
-	root.Doc.optimalCursor(root.scr, root.Doc.columnCursor)
-	root.Doc.columnCursor = max(root.Doc.columnStart, root.Doc.columnCursor)
+	root.prepareLines(root.scr.lines)
+	root.Doc.columnCursor = root.Doc.optimalCursor(root.scr, root.Doc.columnCursor)
 	root.setMessagef("Set delimiter %s", input)
 }
 
@@ -662,6 +673,38 @@ func (root *Root) setJumpTarget(input string) {
 	root.setMessagef("Set JumpTarget %d", num)
 }
 
+// setVerticalHeader sets the vertical header position.
+func (root *Root) setVerticalHeader(input string) {
+	num, err := specifyOnScreen(input, root.scr.vWidth-1)
+	if err != nil {
+		root.setMessagef("Set vertical header: %s", err.Error())
+		return
+	}
+	root.Doc.HeaderColumn = 0
+	if root.Doc.VerticalHeader == num {
+		return
+	}
+
+	root.Doc.VerticalHeader = num
+	root.setMessagef("Set vertical header %d", num)
+}
+
+// setHeaderColumn sets the vertical header column position.
+func (root *Root) setHeaderColumn(input string) {
+	num, err := strconv.Atoi(input)
+	if err != nil {
+		root.setMessagef("Set vertical header column: %s", ErrInvalidNumber)
+		return
+	}
+	root.Doc.VerticalHeader = 0
+	if root.Doc.HeaderColumn == num {
+		return
+	}
+
+	root.Doc.HeaderColumn = num
+	root.setMessagef("Set vertical header column %d", num)
+}
+
 // resize is a wrapper function that calls viewSync.
 func (root *Root) resize(ctx context.Context) {
 	root.ViewSync(ctx)
@@ -775,8 +818,6 @@ func (root *Root) followAll(ctx context.Context) {
 	current := root.CurrentDoc
 	root.mu.RLock()
 	for n, doc := range root.DocList {
-		doc.width = root.scr.vWidth - root.scr.startX
-		doc.height = root.scr.vHeight - (statusLine + doc.headerHeight)
 		if doc.latestNum != doc.BufEndNum() {
 			current = n
 		}
@@ -827,6 +868,17 @@ func (root *Root) bottomSectionLN(ctx context.Context) int {
 	return lN - (root.Doc.topLN + root.Doc.firstLine() - root.Doc.SectionStartPosition)
 }
 
+// toggleFixedColumn toggles the fixed column.
+func (root *Root) toggleFixedColumn(ctx context.Context) {
+	cursor := root.Doc.columnCursor - root.Doc.columnStart + 1
+	if root.Doc.HeaderColumn == cursor {
+		cursor = 0
+	}
+	root.Doc.HeaderColumn = cursor
+	root.Doc.VerticalHeader = 0
+	root.setMessagef("Set Header Column %d", cursor)
+}
+
 // ShrinkColumn shrinks the specified column.
 func (root *Root) ShrinkColumn(ctx context.Context, cursor int) error {
 	return root.Doc.shrinkColumn(cursor, true)
@@ -837,8 +889,8 @@ func (root *Root) ExpandColumn(ctx context.Context, cursor int) error {
 	return root.Doc.shrinkColumn(cursor, false)
 }
 
-// toggleColumnShrink shrinks or expands the current cursor column.
-func (root *Root) toggleColumnShrink(ctx context.Context) {
+// toggleShrinkColumn shrinks or expands the current cursor column.
+func (root *Root) toggleShrinkColumn(ctx context.Context) {
 	cursor := root.Doc.columnCursor
 	shrink, err := root.Doc.isColumnShrink(cursor)
 	if err != nil {
@@ -849,26 +901,56 @@ func (root *Root) toggleColumnShrink(ctx context.Context) {
 	}
 }
 
+// shinkColumn shrinks or expands the specified column.
+func (m *Document) shrinkColumn(cursor int, shrink bool) error {
+	if err := m.isValidColumn(cursor); err != nil {
+		return err
+	}
+	m.alignConv.columnAttrs[cursor].shrink = shrink
+	m.ClearCache()
+	return nil
+}
+
 // isColumnShrink returns whether the specified column is shrink.
 func (m *Document) isColumnShrink(cursor int) (bool, error) {
-	if m.Converter != convAlign {
-		return false, ErrNotAlignMode
-	}
-	if cursor < 0 || cursor >= len(m.alignConv.columnAttrs) {
-		return false, ErrNoColumnSelected
+	if err := m.isValidColumn(cursor); err != nil {
+		return false, err
 	}
 	return m.alignConv.columnAttrs[cursor].shrink, nil
 }
 
-// shinkColumn shrinks or expands the specified column.
-func (m *Document) shrinkColumn(cursor int, shrink bool) error {
+// toggleRightAlign toggles the right align of the current cursor column.
+func (root *Root) toggleRightAlign(ctx context.Context) {
+	m := root.Doc
+	align, err := m.toggleRightAlign(m.columnCursor)
+	if err != nil {
+		root.setMessage(err.Error())
+		return
+	}
+	root.setMessagef("Set %s", align)
+}
+
+// toggleRightAlign toggles the right align of the specified column.
+func (m *Document) toggleRightAlign(cursor int) (specifiedAlign, error) {
+	if err := m.isValidColumn(cursor); err != nil {
+		return Unspecified, err
+	}
+	align := m.alignConv.columnAttrs[cursor].specifiedAlign + 1
+	if align > LeftAlign {
+		align = RightAlign
+	}
+	m.alignConv.columnAttrs[cursor].specifiedAlign = align
+	m.ClearCache()
+	return align, nil
+}
+
+// isValidColumn checks if the specified column is valid.
+func (m *Document) isValidColumn(cursor int) error {
 	if m.Converter != convAlign {
 		return ErrNotAlignMode
 	}
 	if cursor < 0 || cursor >= len(m.alignConv.columnAttrs) {
 		return ErrNoColumnSelected
 	}
-	m.alignConv.columnAttrs[cursor].shrink = shrink
-	m.ClearCache()
 	return nil
 }
