@@ -120,8 +120,7 @@ type Document struct {
 	x int
 	// columnCursor is the number of columns.
 	columnCursor int
-
-	// columnStart is the starting position of the column 0 or 1.
+	// columnStart is the starting position of the column.
 	columnStart int
 
 	// lastSearchLN is the last search line number.
@@ -209,6 +208,8 @@ type LineC struct {
 	str string
 	// for converting the width of str and lc.
 	pos widthPos
+	// columnRanges is the range of columnRanges.
+	columnRanges []columnRange
 	// valid is true if the line is valid.
 	valid bool
 	// The number of the section in the screen.
@@ -219,6 +220,12 @@ type LineC struct {
 	eolStyle tcell.Style
 }
 
+// columnRange represents the start and end positions of a columnRange.
+type columnRange struct {
+	start int
+	end   int
+}
+
 // NewDocument creates and initializes a new [Document] with default settings.
 // It returns a pointer to the Document and an error if the cache initialization fails.
 func NewDocument() (*Document, error) {
@@ -491,12 +498,12 @@ func (m *Document) contentsLine(lN int) (contents, tcell.Style, error) {
 // getLineC returns the content of the specified line number.
 // If the line number does not exist, EOF content is returned.
 func (m *Document) getLineC(lN int) LineC {
-	if line, ok := m.cache.Get(lN); ok {
-		lc := make(contents, len(line.lc))
-		copy(lc, line.lc)
-		line.lc = lc
-		line.valid = true
-		return line
+	if lineC, ok := m.cache.Get(lN); ok {
+		lc := make(contents, len(lineC.lc))
+		copy(lc, lineC.lc)
+		lineC.lc = lc
+		lineC.valid = true
+		return lineC
 	}
 
 	org, style, err := m.contentsLine(lN)
@@ -511,21 +518,21 @@ func (m *Document) getLineC(lN int) LineC {
 		}
 	}
 	str, pos := ContentsToStr(org)
-	line := LineC{
+	lineC := LineC{
 		lc:       org,
 		str:      str,
 		pos:      pos,
 		eolStyle: style,
 	}
 	if err == nil {
-		m.cache.Add(lN, line)
+		m.cache.Add(lN, lineC)
 	}
 
 	lc := make(contents, len(org))
 	copy(lc, org)
-	line.lc = lc
-	line.valid = true
-	return line
+	lineC.lc = lc
+	lineC.valid = true
+	return lineC
 }
 
 // firstLine is the first line that excludes the SkipLines and Header.
@@ -599,6 +606,17 @@ func (m *Document) setColumnWidths() {
 	m.columnWidths = guesswidth.Positions(buf, header, 2)
 }
 
+// vHeaderWidth returns the width of the header.
+func (m *Document) vHeaderWidth(lineC LineC) int {
+	if m.VerticalHeader > 0 {
+		return m.VerticalHeader
+	}
+	if m.HeaderColumn > 0 && m.HeaderColumn < len(lineC.columnRanges) {
+		return lineC.columnRanges[(m.HeaderColumn+m.columnStart)-1].end
+	}
+	return 0
+}
+
 // GetLine returns one line from buffer.
 // Deprecated: Use [Document.LineString] instead.
 func (m *Document) GetLine(n int) string {
