@@ -4,7 +4,6 @@ import (
 	"context"
 	"fmt"
 	"log"
-	"strings"
 	"time"
 
 	"github.com/gdamore/tcell/v2"
@@ -20,6 +19,7 @@ func (root *Root) draw(ctx context.Context) {
 	// Prepare the screen for drawing.
 	root.prepareDraw(ctx)
 
+	root.drawRuler()
 	// Body.
 	lX := m.topLX
 	lN := m.topLN + root.scr.headerEnd
@@ -56,23 +56,26 @@ func (root *Root) drawBody(lX int, lN int) (int, int) {
 
 	wrapNum := m.numOfWrap(lX, lN)
 	for y := m.headerHeight; y < root.scr.vHeight-statusLine; y++ {
-		line, ok := root.scr.lines[lN]
+		lineC, ok := root.scr.lines[lN]
 		if !ok {
-			panic(fmt.Sprintf("line is not found %d", lN))
+			log.Panicf("line is not found %d", lN)
 		}
 		root.scr.numbers[y] = newLineNumber(lN, wrapNum)
-		root.drawLineNumber(lN, y, line.valid)
+		root.drawLineNumber(lN, y, lineC.valid)
 
-		nextLX, nextLN := root.drawLine(y, lX, lN, line)
-		if line.valid {
-			root.coordinatesStyle(lN, y)
-		}
+		nextLX, nextLN := root.drawLine(y, lX, lN, lineC)
 		if root.Doc.SectionHeader {
-			root.sectionLineHighlight(y, line)
+			root.sectionLineHighlight(y, lineC)
 			if root.Doc.HideOtherSection {
-				root.hideOtherSection(y, line)
+				root.hideOtherSection(y, lineC)
 			}
 		}
+
+		root.drawVerticalHeader(y, wrapNum, lineC)
+		if lineC.valid {
+			root.coordinatesStyle(lN, y)
+		}
+
 		root.applyMarkStyle(lN, y, markStyleWidth)
 
 		wrapNum++
@@ -94,15 +97,16 @@ func (root *Root) drawHeader() {
 	wrapNum := 0
 	lX := 0
 	lN := root.scr.headerLN
-	for y := 0; y < m.headerHeight && lN < root.scr.headerEnd; y++ {
+	for y := root.scr.startY; y < m.headerHeight && lN < root.scr.headerEnd; y++ {
 		lineC, ok := root.scr.lines[lN]
 		if !ok {
-			panic(fmt.Sprintf("line is not found %d", lN))
+			log.Panicf("line is not found %d", lN)
 		}
 		root.scr.numbers[y] = newLineNumber(lN, wrapNum)
 		root.blankLineNumber(y)
 
 		lX, lN = root.drawLine(y, lX, lN, lineC)
+		root.drawVerticalHeader(y, wrapNum, lineC)
 		// header style.
 		root.applyStyleToLine(y, root.StyleHeader)
 
@@ -111,6 +115,9 @@ func (root *Root) drawHeader() {
 			wrapNum = 0
 		}
 	}
+	if root.scr.headerEnd > 0 {
+		root.applyStyleToLine(m.headerHeight-1, root.StyleHeaderBorder)
+	}
 }
 
 // drawSectionHeader draws section header.
@@ -124,7 +131,7 @@ func (root *Root) drawSectionHeader() {
 	for y := m.headerHeight; y < m.headerHeight+m.sectionHeaderHeight && lN < root.scr.sectionHeaderEnd; y++ {
 		lineC, ok := root.scr.lines[lN]
 		if !ok {
-			panic(fmt.Sprintf("line is not found %d", lN))
+			log.Panicf("line is not found %d", lN)
 		}
 		root.scr.numbers[y] = newLineNumber(lN, wrapNum)
 		root.drawLineNumber(lN, y, lineC.valid)
@@ -132,6 +139,8 @@ func (root *Root) drawSectionHeader() {
 		nextLX, nextLN := root.drawLine(y, lX, lN, lineC)
 		// section header style.
 		root.applyStyleToLine(y, root.StyleSectionLine)
+
+		root.drawVerticalHeader(y, wrapNum, lineC)
 		// markstyle is displayed above the section header.
 		markStyleWidth := min(root.scr.vWidth, m.general.MarkStyleWidth)
 		root.applyMarkStyle(lN, y, markStyleWidth)
@@ -148,6 +157,36 @@ func (root *Root) drawSectionHeader() {
 		lX = nextLX
 		lN = nextLN
 	}
+	root.applyStyleToLine(m.headerHeight+m.sectionHeaderHeight-1, root.StyleSectionHeaderBorder)
+}
+
+// drawRuler draws the ruler.
+func (root *Root) drawRuler() {
+	rulerType := root.Doc.RulerType
+	if rulerType == RulerNone {
+		return
+	}
+
+	startX := 0
+	if !root.Doc.WrapMode && rulerType == RulerRelative {
+		startX = root.scr.startX - root.Doc.x
+	}
+
+	style := applyStyle(defaultStyle, root.StyleRuler)
+	for x := 0; x < root.scr.vWidth; x++ {
+		n := x - startX + 1
+		if n < 0 {
+			continue
+		}
+		numStr := []rune(fmt.Sprintf("%3d", n))
+		if numStr[2] == '0' {
+			root.Screen.SetContent(x-1, 0, numStr[0], nil, style)
+			root.Screen.SetContent(x, 0, numStr[1], nil, style)
+		} else {
+			root.Screen.SetContent(x, 0, ' ', nil, style)
+		}
+		root.Screen.SetContent(x, 1, numStr[2], nil, style)
+	}
 }
 
 // drawWrapLine wraps and draws the contents and returns the next drawing position.
@@ -165,7 +204,6 @@ func (root *Root) drawWrapLine(y int, lX int, lN int, lineC LineC) (int, int) {
 		log.Printf("Illegal lX:%d", lX)
 		return 0, 0
 	}
-
 	screen := root.Screen
 	for n := 0; ; n++ {
 		x := root.scr.startX + n
@@ -185,7 +223,6 @@ func (root *Root) drawWrapLine(y int, lX int, lN int, lineC LineC) (int, int) {
 		}
 		screen.SetContent(x, y, c.mainc, c.combc, c.style)
 	}
-
 	return lX, lN
 }
 
@@ -209,10 +246,65 @@ func (root *Root) drawNoWrapLine(y int, lX int, lN int, lineC LineC) (int, int)
 		screen.SetContent(x, y, c.mainc, c.combc, c.style)
 	}
 	lN++
-
 	return lX, lN
 }
 
+// drawVerticalHeader draws the vertical header.
+func (root *Root) drawVerticalHeader(y int, wrapNum int, lineC LineC) {
+	if root.Doc.WrapMode && wrapNum > 0 {
+		return
+	}
+	if !lineC.valid {
+		return
+	}
+	widthVH := root.Doc.widthVerticalHeader(lineC)
+	if widthVH == 0 {
+		return
+	}
+	if lineC.lc.IsFullWidth(widthVH - 1) {
+		widthVH--
+	}
+
+	screen := root.Screen
+	for n := 0; n < widthVH; n++ {
+		c := DefaultContent
+		if n < len(lineC.lc) {
+			c = lineC.lc[n]
+		}
+		style := applyStyle(c.style, root.StyleVerticalHeader)
+		if n == widthVH-2 && c.width == 2 {
+			style = applyStyle(defaultStyle, root.StyleVerticalHeaderBorder)
+			screen.SetContent(root.scr.startX+n, y, c.mainc, c.combc, style)
+			return
+		} else if n == widthVH-1 {
+			style = applyStyle(defaultStyle, root.StyleVerticalHeaderBorder)
+			screen.SetContent(root.scr.startX+n, y, c.mainc, c.combc, style)
+			return
+		}
+		screen.SetContent(root.scr.startX+n, y, c.mainc, c.combc, style)
+	}
+}
+
+// widthVerticalHeader calculates the vertical header value.
+// If VerticalHeader is specified, it returns that as the width.
+// If HeaderColumn is specified, it returns the width of the specified column.
+func (m *Document) widthVerticalHeader(lineC LineC) int {
+	if m.VerticalHeader > 0 {
+		return m.VerticalHeader
+	}
+
+	if m.HeaderColumn <= 0 {
+		return 0
+	}
+	vhc := m.HeaderColumn
+	columns := lineC.columnRanges
+	if len(columns) == 0 {
+		return 0
+	}
+	vhc = min(vhc+m.columnStart, len(columns))
+	return columns[vhc-1].end + 1
+}
+
 // blankLineNumber should be blank for the line number.
 func (root *Root) blankLineNumber(y int) {
 	if !root.Doc.LineNumMode {
@@ -221,8 +313,9 @@ func (root *Root) blankLineNumber(y int) {
 	if root.scr.startX <= 0 {
 		return
 	}
-	numC := StrToContents(strings.Repeat(" ", root.scr.startX-1), root.Doc.TabWidth)
-	root.setContentString(0, y, numC)
+	for x := 0; x < root.scr.startX-1; x++ {
+		root.Screen.SetContent(x, y, ' ', nil, defaultStyle)
+	}
 }
 
 // drawLineNumber draws the line number.
@@ -246,14 +339,15 @@ func (root *Root) drawLineNumber(lN int, y int, valid bool) {
 			number = n
 		}
 	}
+	// Line numbers start at 1 except for skip and header lines.
 	number = number - m.firstLine() + 1
 
-	// Line numbers start at 1 except for skip and header lines.
-	numC := StrToContents(fmt.Sprintf("%*d", root.scr.startX-1, number), m.TabWidth)
+	style := applyStyle(defaultStyle, root.StyleLineNumber)
+	numC := []rune(fmt.Sprintf("%*d", root.scr.startX-1, number))
 	for i := 0; i < len(numC); i++ {
-		numC[i].style = applyStyle(defaultStyle, root.StyleLineNumber)
+		root.Screen.SetContent(i, y, numC[i], nil, style)
 	}
-	root.setContentString(0, y, numC)
+	root.Screen.SetContent(len(numC), y, ' ', nil, defaultStyle)
 }
 
 // setContentString is a helper function that draws a string with setContent.
@@ -279,7 +373,9 @@ func (root *Root) clearY(y int) {
 
 // coordinatesStyle applies the style of the coordinates.
 func (root *Root) coordinatesStyle(lN int, y int) {
-	root.applyStyleToAlternate(lN, y)
+	if root.Doc.AlternateRows {
+		root.applyStyleToAlternate(lN, y)
+	}
 	if root.Doc.jumpTargetHeight != 0 && root.Doc.headerHeight+root.Doc.jumpTargetHeight == y {
 		root.applyStyleToLine(y, root.StyleJumpTargetLine)
 	}
@@ -287,9 +383,6 @@ func (root *Root) coordinatesStyle(lN int, y int) {
 
 // applyStyleToAlternate applies from beginning to end of line.
 func (root *Root) applyStyleToAlternate(lN int, y int) {
-	if !root.Doc.AlternateRows {
-		return
-	}
 	if (lN)%2 == 0 {
 		return
 	}
