@@ -98,6 +98,10 @@ func (root *Root) event(ctx context.Context, ev tcell.Event) bool {
 		root.saveBuffer(ev.value)
 	case *eventSectionNum:
 		root.setSectionNum(ev.value)
+	case *eventVerticalHeader:
+		root.setVerticalHeader(ev.value)
+	case *eventHeaderColumn:
+		root.setHeaderColumn(ev.value)
 	case *eventReachEOF:
 		root.notifyEOFReached(ev.m)
 
@@ -148,8 +152,6 @@ func (root *Root) everyUpdate(ctx context.Context) {
 		}
 	}
 
-	root.Doc.width = root.scr.vWidth - root.scr.startX
-	root.Doc.height = root.Doc.statusPos - root.Doc.headerHeight
 	switch {
 	case root.General.FollowAll:
 		root.followAll(ctx)
