@@ -2,7 +2,6 @@ package oviewer
 
 import (
 	"context"
-	"fmt"
 	"io"
 	"log"
 	"strings"
@@ -34,6 +33,8 @@ func (root *Root) filter(ctx context.Context, str string) {
 	root.filterDocument(ctx, searcher)
 }
 
+// filterDocument filters the document by the searcher.
+// It creates a new document and writes the filtered lines to it.
 func (root *Root) filterDocument(ctx context.Context, searcher Searcher) {
 	m := root.Doc
 	r, w := io.Pipe()
@@ -47,8 +48,8 @@ func (root *Root) filterDocument(ctx context.Context, searcher Searcher) {
 	if m.nonMatch {
 		match = "!" + match
 	}
-	render.Caption = fmt.Sprintf("filter:%s", match)
-	msg := fmt.Sprintf("search:%s", match)
+	render.Caption = "filter:" + match
+	msg := "search:" + match
 	root.insertDocument(ctx, root.CurrentDoc, render)
 	render.general = mergeGeneral(root.Config.General, render.general)
 	render.regexpCompile()
@@ -72,7 +73,7 @@ func (root *Root) filterDocument(ctx context.Context, searcher Searcher) {
 		writeLine(w, line)
 	}
 	go m.filterWriter(ctx, searcher, m.firstLine(), filterDoc)
-	root.setMessagef(msg)
+	root.setMessage(msg)
 }
 
 // filterWriter searches and writes to filterDoc.
@@ -119,7 +120,6 @@ func (root *Root) closeAllFilter(ctx context.Context) {
 		return
 	}
 	root.setMessageLogf("close %s", strings.Join(closed, ", "))
-
 }
 
 // writeLine writes a line to w.
