@@ -20,13 +20,17 @@ func NewHelp(k KeyBind) (*Document, error) {
 	helpStr := bytes.NewBufferString("\t\t\t" + gchalk.WithUnderline().Bold("ov help"))
 	helpStr.WriteString("\n")
 	helpStr.WriteString(KeyBindString(k))
+	// Duplicate key bindings.
+	helpStr.WriteString(DuplicateKeyBind(k))
 
-	m.FileName = "Help"
+	m.Caption = "Help"
 	m.store.eof = 1
 	m.preventReload = true
 	m.seekable = false
+	m.Header = 2
 	m.SectionHeader = true
 	m.setSectionDelimiter("\t")
+	m.SectionHeaderNum = 1
 	atomic.StoreInt32(&m.closed, 1)
 	if err := m.ControlReader(helpStr, nil); err != nil {
 		return nil, err
@@ -47,3 +51,17 @@ func KeyBindString(k KeyBind) string {
 	}
 	return buf.String()
 }
+
+func DuplicateKeyBind(k KeyBind) string {
+	w := &strings.Builder{}
+	dupkey := findDuplicateKeyBind(k)
+	if len(dupkey) == 0 {
+		return ""
+	}
+	fmt.Fprintf(w, "\n\tDuplicate key bindings:\n")
+	for _, v := range dupkey {
+		v.key = strings.TrimPrefix(v.key, "input_")
+		fmt.Fprintf(w, "%s [%s] for %s\n", gchalk.Red("Duplicate key"), v.key, strings.Join(v.action, ", "))
+	}
+	return w.String()
+}
