@@ -2,6 +2,7 @@ package oviewer
 
 import (
 	"context"
+	"strconv"
 	"sync"
 
 	"github.com/gdamore/tcell/v2"
@@ -31,6 +32,9 @@ const (
 	JumpTarget                 // JumpTarget is the position to display the search results.
 	SaveBuffer                 // SaveBuffer is the save buffer.
 	SectionNum                 // SectionNum is the section number.
+	ConvertType                // ConvertType is the convert type.
+	VerticalHeader             // VerticalHeader is the number of vertical headers input mode.
+	HeaderColumn               // HeaderColumn is the number of vertical header columns input mode.
 )
 
 // Input represents the status of various inputs.
@@ -52,6 +56,7 @@ type Input struct {
 	MultiColorCandidate   *candidate
 	JumpTargetCandidate   *candidate
 	SaveBufferCandidate   *candidate
+	ConverterCandidate    *candidate
 
 	value   string
 	cursorX int
@@ -73,6 +78,7 @@ func NewInput() *Input {
 	i.MultiColorCandidate = multiColorCandidate()
 	i.JumpTargetCandidate = jumpTargetCandidate()
 	i.SaveBufferCandidate = blankCandidate()
+	i.ConverterCandidate = converterCandidate()
 
 	i.Event = &eventNormal{}
 	return &i
@@ -82,7 +88,7 @@ func NewInput() *Input {
 func (root *Root) inputEvent(ctx context.Context, ev *tcell.EventKey) {
 	// inputEvent returns input confirmed or not confirmed.
 	// Not confirmed or canceled.
-	evKey := root.inputKeyConfig.Capture(ev)
+	evKey := root.inputCapture(ev)
 	if ok := root.input.keyEvent(evKey); !ok {
 		root.incrementalSearch(ctx)
 		return
@@ -100,6 +106,19 @@ func (root *Root) inputEvent(ctx context.Context, ev *tcell.EventKey) {
 	input.Event = normal()
 }
 
+func (root *Root) inputCapture(ev *tcell.EventKey) *tcell.EventKey {
+	if ev.Rune() == '!' {
+		if root.input.Event.Mode() != Filter {
+			return ev
+		}
+		if len(root.input.value) > 0 && root.input.value[len(root.input.value)-1] == '\\' {
+			return ev
+		}
+	}
+
+	return root.inputKeyConfig.Capture(ev)
+}
+
 // keyEvent handles the keystrokes of the input.
 func (input *Input) keyEvent(evKey *tcell.EventKey) bool {
 	if evKey == nil {
@@ -358,3 +377,21 @@ func blankCandidate() *candidate {
 		list: []string{},
 	}
 }
+
+// upNum returns the number of the previous candidate.
+func upNum(str string) string {
+	n, err := strconv.Atoi(str)
+	if err != nil {
+		return "0"
+	}
+	return strconv.Itoa(n + 1)
+}
+
+// downNum returns the number of the next candidate.
+func downNum(str string) string {
+	n, err := strconv.Atoi(str)
+	if err != nil || n <= 0 {
+		return "0"
+	}
+	return strconv.Itoa(n - 1)
+}
