@@ -1,6 +1,7 @@
 package oviewer
 
 import (
+	"context"
 	"strings"
 
 	"github.com/gdamore/tcell/v2"
@@ -10,7 +11,7 @@ import (
 const searchCandidateListLen = 10
 
 // setMultiColorMode sets the inputMode to MultiColor.
-func (root *Root) setMultiColorMode() {
+func (root *Root) setMultiColorMode(context.Context) {
 	input := root.input
 	input.reset()
 
@@ -50,7 +51,7 @@ func (*eventMultiColor) Mode() InputMode {
 
 // Prompt returns the prompt string in the input field.
 func (*eventMultiColor) Prompt() string {
-	return "multicolor:"
+	return "Multi color:"
 }
 
 // Confirm returns the event when the input is confirmed.
