@@ -85,7 +85,12 @@ const (
 	actionConvertType    = "convert_type"
 	actionAlignFormat    = "align_format"
 	actionRawFormat      = "raw_format"
+	actionVerticalHeader = "vertical_header"
+	actionHeaderColumn   = "header_column"
+	actionFixedColumn    = "fixed_column"
 	actionShrinkColumn   = "shrink_column"
+	actionRightAlign     = "right_align"
+	actionRuler          = "toggle_ruler"
 
 	inputCaseSensitive      = "input_casesensitive"
 	inputSmartCaseSensitive = "input_smart_casesensitive"
@@ -173,7 +178,12 @@ func (root *Root) handlers() map[string]func(context.Context) {
 		actionConvertType:    root.setConvertType,
 		actionAlignFormat:    root.alignFormat,
 		actionRawFormat:      root.rawFormat,
-		actionShrinkColumn:   root.toggleColumnShrink,
+		actionVerticalHeader: root.setVerticalHeaderMode,
+		actionHeaderColumn:   root.setHeaderColumnMode,
+		actionFixedColumn:    root.toggleFixedColumn,
+		actionShrinkColumn:   root.toggleShrinkColumn,
+		actionRightAlign:     root.toggleRightAlign,
+		actionRuler:          root.toggleRuler,
 
 		inputCaseSensitive:      root.inputCaseSensitive,
 		inputSmartCaseSensitive: root.inputSmartCaseSensitive,
@@ -265,7 +275,12 @@ func defaultKeyBinds() KeyBind {
 		actionConvertType:    {"alt+t"},
 		actionAlignFormat:    {"alt+F"},
 		actionRawFormat:      {"alt+R"},
+		actionVerticalHeader: {"y"},
+		actionHeaderColumn:   {"Y"},
+		actionFixedColumn:    {"F"},
 		actionShrinkColumn:   {"s"},
+		actionRightAlign:     {"alt+a"},
+		actionRuler:          {"alt+shift+F9"},
 
 		inputCaseSensitive:      {"alt+c"},
 		inputSmartCaseSensitive: {"alt+s"},
@@ -340,12 +355,12 @@ func (k KeyBind) String() string {
 	k.writeKeyBind(&b, actionColumnMode, "column mode toggle")
 	k.writeKeyBind(&b, actionColumnWidth, "column width toggle")
 	k.writeKeyBind(&b, actionRainbow, "column rainbow toggle")
-	k.writeKeyBind(&b, actionShrinkColumn, "shrink column toggle")
 	k.writeKeyBind(&b, actionAlternate, "alternate rows of style toggle")
 	k.writeKeyBind(&b, actionLineNumMode, "line number toggle")
 	k.writeKeyBind(&b, actionPlain, "original decoration toggle(plain)")
 	k.writeKeyBind(&b, actionAlignFormat, "align columns")
 	k.writeKeyBind(&b, actionRawFormat, "raw output")
+	k.writeKeyBind(&b, actionRuler, "ruler toggle")
 
 	writeHeader(&b, "Change Display with Input")
 	k.writeKeyBind(&b, actionViewMode, "view mode selection")
@@ -356,8 +371,15 @@ func (k KeyBind) String() string {
 	k.writeKeyBind(&b, actionMultiColor, "multi color highlight")
 	k.writeKeyBind(&b, actionJumpTarget, "jump target(`.n` or `n%` or `section` allowed)")
 	k.writeKeyBind(&b, actionConvertType, "convert type selection")
+	k.writeKeyBind(&b, actionVerticalHeader, "number of vertical header")
+	k.writeKeyBind(&b, actionHeaderColumn, "number of header column")
 
-	writeHeader(&b, "Section")
+	writeHeader(&b, "Column operation")
+	k.writeKeyBind(&b, actionFixedColumn, "header column fixed toggle")
+	k.writeKeyBind(&b, actionShrinkColumn, "shrink column toggle(align mode only)")
+	k.writeKeyBind(&b, actionRightAlign, "right align column toggle(align mode only)")
+
+	writeHeader(&b, "Section operation")
 	k.writeKeyBind(&b, actionSection, "section delimiter regular expression")
 	k.writeKeyBind(&b, actionSectionStart, "section start position")
 	k.writeKeyBind(&b, actionNextSection, "next section")
@@ -381,7 +403,7 @@ func (k KeyBind) String() string {
 	k.writeKeyBind(&b, inputNonMatch, "non-match toggle")
 	k.writeKeyBind(&b, inputPrevious, "previous candidate")
 	k.writeKeyBind(&b, inputNext, "next candidate")
-	k.writeKeyBind(&b, inputCopy, "copy to clipboard.")
+	k.writeKeyBind(&b, inputCopy, "copy to clipboard")
 	k.writeKeyBind(&b, inputPaste, "paste from clipboard")
 	return b.String()
 }
@@ -398,7 +420,17 @@ func (k KeyBind) writeKeyBind(w io.Writer, action string, detail string) {
 	fmt.Fprintf(w, " %-30s * %s\n", "["+strings.Join(k[action], "], [")+"]", detail)
 }
 
-// GetKeyBinds returns the current key mapping.
+// GetKeyBinds returns the current key mapping based on the provided configuration.
+// If the default key bindings are not disabled in the configuration, it initializes
+// the key bindings with the default values and then overwrites them with any custom
+// key bindings specified in the configuration file.
+//
+// Parameters:
+//   - config: The configuration object that contains the key binding settings.
+//
+// Returns:
+//   - KeyBind: A map where the keys are action names and the values are slices of
+//     strings representing the keys assigned to those actions.
 func GetKeyBinds(config Config) KeyBind {
 	keyBind := make(map[string][]string)
 
@@ -480,3 +512,31 @@ func (root *Root) keyCapture(ev *tcell.EventKey) bool {
 	root.keyConfig.Capture(ev)
 	return true
 }
+
+type duplicate struct {
+	key    string
+	action []string
+}
+
+func findDuplicateKeyBind(keyBind KeyBind) []duplicate {
+	keyActions := make(map[string]duplicate)
+	for k, v := range keyBind {
+		for _, key := range v {
+			if strings.HasPrefix(k, "input_") {
+				key = "input_" + key
+			}
+			if _, ok := keyActions[key]; ok {
+				keyActions[key] = duplicate{key: key, action: append(keyActions[key].action, k)}
+			} else {
+				keyActions[key] = duplicate{key: key, action: []string{k}}
+			}
+		}
+	}
+	q := make([]duplicate, 0, len(keyActions))
+	for _, v := range keyActions {
+		if len(v.action) > 1 {
+			q = append(q, v)
+		}
+	}
+	return q
+}
