@@ -18,15 +18,15 @@ import (
 	"github.com/gdamore/tcell/v2"
 )
 
-// Root structure contains information about the drawing.
+// Root is the root structure of the oviewer.
 type Root struct {
 	// tcell.Screen is the root screen.
 	tcell.Screen
-	// Doc contains the model of ov
+	// Doc is the current document.
 	Doc *Document
-	// help
+	// helpDoc is the help document.
 	helpDoc *Document
-	// log
+	// logDoc is the log document.
 	logDoc *LogDocument
 
 	// input contains the input mode.
@@ -34,7 +34,7 @@ type Root struct {
 	// cancelFunc saves the cancel function, which is a time-consuming process.
 	cancelFunc context.CancelFunc
 
-	// searcher is the searcher.
+	// searcher is the search structure.
 	searcher Searcher
 
 	// keyConfig contains the binding settings for the key.
@@ -90,7 +90,10 @@ type SCR struct {
 	vHeight int
 	// startX is the start position of x.
 	startX int
-
+	// startY is the start position of y.
+	startY int
+	// rulerHeight is the height of the ruler.
+	rulerHeight int
 	// HeaderLN is the number of header lines.
 	headerLN int
 	// headerEnd is the end of the header.
@@ -99,6 +102,10 @@ type SCR struct {
 	sectionHeaderLN int
 	// sectionHeaderEnd is the end of the section header.
 	sectionHeaderEnd int
+	// bodyLN is the number of body lines.
+	bodyLN int
+	// bodyEnd is the end of the body.
+	bodyEnd int
 
 	// x1, y1, x2, y2 are the coordinates selected by the mouse.
 	x1 int
@@ -123,6 +130,29 @@ func newLineNumber(number, wrap int) LineNumber {
 	return LineNumber{number: number, wrap: wrap}
 }
 
+const MinStartX = -10
+
+// RulerType is the type of ruler.
+type RulerType int
+
+const (
+	RulerNone RulerType = iota
+	RulerRelative
+	RulerAbsolute
+)
+
+// String returns the string representation of the ruler type.
+func (r RulerType) String() string {
+	switch r {
+	case RulerRelative:
+		return "relative"
+	case RulerAbsolute:
+		return "absolute"
+	default:
+		return "none"
+	}
+}
+
 // general structure contains the general of the display.
 // general contains values that determine the behavior of each document.
 type general struct {
@@ -147,6 +177,11 @@ type general struct {
 	TabWidth int
 	// Header is number of header lines to be fixed.
 	Header int
+	// VerticalHeader is the number of vertical header lines.
+	VerticalHeader int
+	// HeaderColumn is the number of columns from the left to be fixed.
+	// If 0 is specified, no columns are fixed.
+	HeaderColumn int
 	// SkipLines is the rows to skip.
 	SkipLines int
 	// WatchInterval is the watch interval (seconds).
@@ -161,6 +196,8 @@ type general struct {
 	HScrollWidth string
 	// HScrollWidthNum is the horizontal scroll width.
 	HScrollWidthNum int
+	// RulerType is the ruler type (0: none, 1: relative, 2: absolute).
+	RulerType RulerType
 	// AlternateRows alternately style rows.
 	AlternateRows bool
 	// ColumnMode is column mode.
@@ -189,102 +226,6 @@ type general struct {
 	HideOtherSection bool
 }
 
-// OVPromptConfigNormal is the normal prompt setting.
-type OVPromptConfigNormal struct {
-	// ShowFilename controls whether to display filename.
-	ShowFilename bool
-	// InvertColor controls whether the text is colored and inverted.
-	InvertColor bool
-	// ProcessOfCount controls whether to display the progress of the count.
-	ProcessOfCount bool
-}
-
-// OVPromptConfig is the prompt setting.
-type OVPromptConfig struct {
-	// Normal is the normal prompt setting.
-	Normal OVPromptConfigNormal
-}
-
-// Config represents the settings of ov.
-type Config struct {
-	// KeyBinding
-	Keybind map[string][]string
-	// Mode represents the operation of the customized mode.
-	Mode map[string]general
-	// ViewMode represents the view mode.
-	// ViewMode sets several settings together and can be easily switched.
-	ViewMode string
-	// Default keybindings. Disabled if the default keybinding is "disable".
-	DefaultKeyBind string
-	// StyleColumnRainbow  is the style that applies to the column rainbow color highlight.
-	StyleColumnRainbow []OVStyle
-	// StyleMultiColorHighlight is the style that applies to the multi color highlight.
-	StyleMultiColorHighlight []OVStyle
-
-	// Prompt is the prompt setting.
-	Prompt OVPromptConfig
-
-	// StyleHeader is the style that applies to the header.
-	StyleHeader OVStyle
-	// StyleBody is the style that applies to the body.
-	StyleBody OVStyle
-	// StyleLineNumber is a style that applies line number.
-	StyleLineNumber OVStyle
-	// StyleSearchHighlight is the style that applies to the search highlight.
-	StyleSearchHighlight OVStyle
-	// StyleColumnHighlight is the style that applies to the column highlight.
-	StyleColumnHighlight OVStyle
-	// StyleMarkLine is a style that marked line.
-	StyleMarkLine OVStyle
-	// StyleSectionLine is a style that section delimiter line.
-	StyleSectionLine OVStyle
-	// StyleJumpTargetLine is the line that displays the search results.
-	StyleJumpTargetLine OVStyle
-	// StyleAlternate is a style that applies line by line.
-	StyleAlternate OVStyle
-	// StyleOverStrike is a style that applies to overstrike.
-	StyleOverStrike OVStyle
-	// StyleOverLine is a style that applies to overstrike underlines.
-	StyleOverLine OVStyle
-	// General represents the general behavior.
-	General general
-	// BeforeWriteOriginal specifies the number of lines before the current position.
-	// 0 is the top of the current screen
-	BeforeWriteOriginal int
-	// AfterWriteOriginal specifies the number of lines after the current position.
-	// 0 specifies the bottom of the screen.
-	AfterWriteOriginal int
-	// MemoryLimit is a number that limits chunk loading.
-	MemoryLimit int
-	// MemoryLimitFile is a number that limits the chunks loading a file into memory.
-	MemoryLimitFile int
-	// Mouse support disable.
-	DisableMouse bool
-	// IsWriteOriginal is true, write the current screen on quit.
-	IsWriteOriginal bool
-	// QuitSmall Quit if the output fits on one screen.
-	QuitSmall bool
-	// QuitSmallFilter Quit if the output fits on one screen and the filter is applied.
-	QuitSmallFilter bool
-	// CaseSensitive is case-sensitive if true.
-	CaseSensitive bool
-	// SmartCaseSensitive is lowercase search ignores case, if true.
-	SmartCaseSensitive bool
-	// RegexpSearch is Regular expression search if true.
-	RegexpSearch bool
-	// Incsearch is incremental search if true.
-	Incsearch bool
-	// NotifyEOF specifies the number of times to notify EOF.
-	NotifyEOF int
-
-	// ShrinkChar is the character to display when the column is shrunk.
-	ShrinkChar string
-	// DisableColumnCycle is disable column cycle.
-	DisableColumnCycle bool
-	// Debug represents whether to enable the debug output.
-	Debug bool
-}
-
 var (
 	// MemoryLimit is a number that limits the chunks to load into memory.
 	MemoryLimit int
@@ -390,8 +331,8 @@ var (
 	ErrNoColumnSelected = errors.New("no column selected")
 	// ErrInvalidSGR indicates that the SGR is invalid.
 	ErrInvalidSGR = errors.New("invalid SGR")
-	// ErrNotSuuport indicates that it is not supported.
-	ErrNotSuuport = errors.New("not support")
+	// ErrNotSupport indicates that it is not supported.
+	ErrNotSupport = errors.New("not support")
 	// ErrInvalidDocumentNum indicates that the document number is invalid.
 	ErrInvalidDocumentNum = errors.New("invalid document number")
 )
@@ -406,7 +347,7 @@ func NewOviewer(docs ...*Document) (*Root, error) {
 		return nil, ErrNotFound
 	}
 	root := &Root{
-		minStartX: -10,
+		minStartX: MinStartX,
 	}
 	root.Config = NewConfig()
 	root.keyConfig = cbind.NewConfiguration()
@@ -808,15 +749,57 @@ func (root *Root) debugMessage(msg string) {
 
 // mergeGeneral overwrites a general structure with a struct.
 func mergeGeneral(src general, dst general) general {
+	if dst.Converter != "" {
+		src.Converter = dst.Converter
+	}
+	if dst.ColumnDelimiter != "" {
+		src.ColumnDelimiter = dst.ColumnDelimiter
+	}
+	if dst.SectionDelimiter != "" {
+		src.SectionDelimiter = dst.SectionDelimiter
+	}
+	if dst.JumpTarget != "" {
+		src.JumpTarget = dst.JumpTarget
+	}
+	if len(dst.MultiColorWords) > 0 {
+		src.MultiColorWords = dst.MultiColorWords
+	}
 	if dst.TabWidth != 0 {
 		src.TabWidth = dst.TabWidth
 	}
 	if dst.Header != 0 {
 		src.Header = dst.Header
 	}
+	if dst.VerticalHeader != 0 {
+		src.VerticalHeader = dst.VerticalHeader
+	}
+	if dst.HeaderColumn != 0 {
+		src.HeaderColumn = dst.HeaderColumn
+	}
 	if dst.SkipLines != 0 {
 		src.SkipLines = dst.SkipLines
 	}
+	if dst.WatchInterval != 0 {
+		src.WatchInterval = dst.WatchInterval
+	}
+	if dst.MarkStyleWidth != 0 {
+		src.MarkStyleWidth = dst.MarkStyleWidth
+	}
+	if dst.SectionStartPosition != 0 {
+		src.SectionStartPosition = dst.SectionStartPosition
+	}
+	if dst.SectionHeaderNum != 0 {
+		src.SectionHeaderNum = dst.SectionHeaderNum
+	}
+	if dst.HScrollWidth != "" {
+		src.HScrollWidth = dst.HScrollWidth
+	}
+	if dst.HScrollWidthNum != 0 {
+		src.HScrollWidthNum = dst.HScrollWidthNum
+	}
+	if dst.RulerType != RulerNone {
+		src.RulerType = dst.RulerType
+	}
 	if dst.AlternateRows {
 		src.AlternateRows = dst.AlternateRows
 	}
@@ -847,41 +830,14 @@ func mergeGeneral(src general, dst general) general {
 	if dst.FollowName {
 		src.FollowName = dst.FollowName
 	}
-	if dst.ColumnDelimiter != "" {
-		src.ColumnDelimiter = dst.ColumnDelimiter
-	}
-	if dst.WatchInterval != 0 {
-		src.WatchInterval = dst.WatchInterval
-	}
-	if dst.MarkStyleWidth != 0 {
-		src.MarkStyleWidth = dst.MarkStyleWidth
-	}
-	if dst.SectionDelimiter != "" {
-		src.SectionDelimiter = dst.SectionDelimiter
-	}
-	if dst.SectionStartPosition != 0 {
-		src.SectionStartPosition = dst.SectionStartPosition
-	}
-	if dst.JumpTarget != "" {
-		src.JumpTarget = dst.JumpTarget
-	}
-	if dst.HScrollWidth != "" {
-		src.HScrollWidth = dst.HScrollWidth
-	}
-	if len(dst.MultiColorWords) > 0 {
-		src.MultiColorWords = dst.MultiColorWords
-	}
-	if dst.SectionHeaderNum != 0 {
-		src.SectionHeaderNum = dst.SectionHeaderNum
-	}
-	if dst.Caption != "" {
-		src.Caption = dst.Caption
+	if dst.SectionHeader {
+		src.SectionHeader = dst.SectionHeader
 	}
 	if dst.HideOtherSection {
 		src.HideOtherSection = dst.HideOtherSection
 	}
-	if dst.Converter != "" {
-		src.Converter = dst.Converter
+	if dst.PlainMode {
+		src.PlainMode = dst.PlainMode
 	}
 	return src
 }
