@@ -41,8 +41,8 @@ func sectionStrHelper(t *testing.T, root *Root) string {
 	var buf bytes.Buffer
 	buf.WriteString("|")
 	for _, lN := range lNs {
-		line := lines[lN]
-		buf.WriteString(fmt.Sprintf("(%d)%d-%02d|", lN, line.section, line.sectionNm))
+		lineC := lines[lN]
+		buf.WriteString(fmt.Sprintf("(%d)%d-%02d|", lN, lineC.section, lineC.sectionNm))
 	}
 	return buf.String()
 }
@@ -504,6 +504,8 @@ func TestRoot_prepareLines(t *testing.T) {
 			m.setSectionDelimiter(tt.fields.sectionDelimiter)
 			m.SectionHeaderNum = tt.fields.sectionHeaderNum
 			root.scr.lines = make(map[int]LineC)
+			root.scr.bodyLN = root.Doc.topLN + root.Doc.firstLine()
+			root.scr.bodyEnd = root.scr.bodyLN + root.scr.vHeight
 			root.prepareLines(root.scr.lines)
 			if len(root.scr.lines) != tt.want.num {
 				t.Errorf("screen lines len got: %d, want: %d", len(root.scr.lines), tt.want.num)
@@ -591,8 +593,8 @@ func TestRoot_styleContent(t *testing.T) {
 			m.setColumnWidths()
 			root.scr.lines = make(map[int]LineC)
 			root.prepareDraw(context.Background())
-			line := m.getLineC(tt.args.lineNum)
-			if line.lc == nil {
+			lineC := m.getLineC(tt.args.lineNum)
+			if lineC.lc == nil {
 				t.Fatal("line is nil")
 			}
 		})
@@ -639,15 +641,15 @@ func TestRoot_searchHighlight(t *testing.T) {
 		t.Run(tt.name, func(t *testing.T) {
 			root := sectionHeader1Helper(t)
 
-			line := root.Doc.getLineC(tt.args.lineNum)
+			lineC := root.Doc.getLineC(tt.args.lineNum)
 			root.searcher = tt.fields.searcher
 			root.StyleSearchHighlight = OVStyle{Reverse: true}
-			root.searchHighlight(line)
-			if line.str != tt.want.str {
-				t.Errorf("\nline: %v\nwant: %v\n", line.str, tt.want.str)
+			root.searchHighlight(lineC)
+			if lineC.str != tt.want.str {
+				t.Errorf("\nline: %v\nwant: %v\n", lineC.str, tt.want.str)
 			}
-			if line.lc[tt.want.start].style != searchHighlight {
-				t.Errorf("style got: %v want: %v", line.lc[tt.want.start].style, searchHighlight)
+			if lineC.lc[tt.want.start].style != searchHighlight {
+				t.Errorf("style got: %v want: %v", lineC.lc[tt.want.start].style, searchHighlight)
 			}
 		})
 	}
@@ -741,13 +743,14 @@ func TestRoot_columnDelimiterHighlight(t *testing.T) {
 			m.ColumnDelimiterReg = condRegexpCompile(m.ColumnDelimiter)
 			m.columnCursor = tt.fields.columnCursor
 			root.StyleColumnHighlight = OVStyle{Bold: true}
-			line := root.Doc.getLineC(tt.args.lineNum)
-			root.columnDelimiterHighlight(line)
-			if line.str != tt.want.str {
-				t.Errorf("\nline: %v\nwant: %v\n", line.str, tt.want.str)
+			lineC := root.Doc.getLineC(tt.args.lineNum)
+			lineC.columnRanges = root.Doc.columnDelimiterRange(lineC)
+			root.columnHighlight(lineC)
+			if lineC.str != tt.want.str {
+				t.Errorf("\nline: %v\nwant: %v\n", lineC.str, tt.want.str)
 			}
-			if line.lc[tt.want.start].style != columnHighlight {
-				t.Errorf("style got: %v want: %v", line.lc[tt.want.start].style, columnHighlight)
+			if lineC.lc[tt.want.start].style != columnHighlight {
+				t.Errorf("style got: %v want: %v", lineC.lc[tt.want.start].style, columnHighlight)
 			}
 		})
 	}
@@ -814,18 +817,19 @@ func TestRoot_columnWidthHighlight(t *testing.T) {
 			m.setColumnWidths()
 			t.Log(m.columnWidths)
 			m.columnCursor = tt.fields.columnCursor
-			line := root.Doc.getLineC(tt.args.lineNum)
-			root.columnWidthHighlight(line)
-			if line.str != tt.want.str {
-				t.Errorf("\nline: %v\nwant: %v\n", line.str, tt.want.str)
+			lineC := root.Doc.getLineC(tt.args.lineNum)
+			lineC.columnRanges = root.Doc.columnWidthRanges(lineC)
+			root.columnHighlight(lineC)
+			if lineC.str != tt.want.str {
+				t.Errorf("\nline: %v\nwant: %v\n", lineC.str, tt.want.str)
 			}
-			if line.lc[tt.want.start].style != columnHighlight {
+			if lineC.lc[tt.want.start].style != columnHighlight {
 				v := bytes.Buffer{}
-				for i, l := range line.lc {
+				for i, l := range lineC.lc {
 					v.WriteString(fmt.Sprintf("%d:%v", i, l.style))
 				}
 				t.Logf("style: %v", v.String())
-				t.Errorf("style got: %v want: %v", line.lc[tt.want.start].style, columnHighlight)
+				t.Errorf("style got: %v want: %v", lineC.lc[tt.want.start].style, columnHighlight)
 			}
 		})
 	}
@@ -1106,7 +1110,7 @@ func TestRoot_setAlignConverter(t *testing.T) {
 				header:      1,
 				columnWidth: true,
 			},
-			want: []int{3, 5},
+			want: []int{3, 5, 3},
 		},
 		{
 			name: "Test setAlignConverterDelimiter",
@@ -1116,7 +1120,7 @@ func TestRoot_setAlignConverter(t *testing.T) {
 				columnWidth:     false,
 				columnDelimiter: "|",
 			},
-			want: []int{0, 7, 7, 7},
+			want: []int{0, 7, 7, 7, 1},
 		},
 		{
 			name: "Test setAlignConverterDelimiter2",
@@ -1126,7 +1130,7 @@ func TestRoot_setAlignConverter(t *testing.T) {
 				columnWidth:     false,
 				columnDelimiter: ",",
 			},
-			want: []int{1, 5, 1},
+			want: []int{1, 5, 1, 1},
 		},
 		{
 			name: "Test setAlignNoColumn",
@@ -1169,41 +1173,51 @@ func TestRoot_setAlignConverter(t *testing.T) {
 func Test_maxWidthsDelm(t *testing.T) {
 	type args struct {
 		maxWidths    []int
+		rightCount   []int
 		delimiter    string
 		delimiterReg *regexp.Regexp
 	}
 	tests := []struct {
-		name string
-		str  string
-		args args
-		want []int
+		name  string
+		str   string
+		args  args
+		want1 []int
+		want2 []int
 	}{
 		{
 			name: "Test maxWidthsDelm1",
 			str:  "a, b, c, d, e, f, g",
 			args: args{
 				maxWidths:    []int{0, 0, 0, 0, 0},
+				rightCount:   []int{0, 0, 0, 0, 0},
 				delimiter:    ",",
 				delimiterReg: regexpCompile(",", false),
 			},
-			want: []int{1, 2, 2, 2, 2, 2},
+			want1: []int{1, 2, 2, 2, 2, 2, 2},
+			want2: []int{0, 0, 0, 0, 0, 0, 0},
 		},
 		{
 			name: "Test maxWidthsDelm2",
 			str:  "no delimiter",
 			args: args{
 				maxWidths:    []int{2, 2, 2, 2, 2, 2},
+				rightCount:   []int{0, 0, 0, 0, 0, 0},
 				delimiter:    ",",
 				delimiterReg: regexpCompile(",", false),
 			},
-			want: []int{2, 2, 2, 2, 2, 2},
+			want1: []int{2, 2, 2, 2, 2, 2},
+			want2: []int{0, 0, 0, 0, 0, 0},
 		},
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
 			lc := StrToContents(tt.str, 8)
-			if got := maxWidthsDelm(lc, tt.args.maxWidths, tt.args.delimiter, tt.args.delimiterReg); !reflect.DeepEqual(got, tt.want) {
-				t.Errorf("maxWidthsDelm() = %v, want %v", got, tt.want)
+			got1, got2 := maxWidthsDelm(lc, tt.args.maxWidths, tt.args.rightCount, tt.args.delimiter, tt.args.delimiterReg)
+			if !reflect.DeepEqual(got1, tt.want1) {
+				t.Errorf("maxWidthsDelm() = %v, want %v", got1, tt.want1)
+			}
+			if !reflect.DeepEqual(got2, tt.want2) {
+				t.Errorf("maxWidthsDelm() = %v, want %v", got2, tt.want2)
 			}
 		})
 	}
@@ -1230,14 +1244,14 @@ func Test_maxWidthsWidth(t *testing.T) {
 				widths:    []int{2, 11},
 				addRight:  []int{0, 0},
 			},
-			want:  []int{1, 4},
-			want2: []int{0, 0},
+			want:  []int{1, 4, 2},
+			want2: []int{0, 0, 1},
 		},
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
 			lc := StrToContents(tt.str, 8)
-			got, got2 := maxWidthsWidth(lc, tt.args.maxWidths, tt.args.widths, tt.args.addRight)
+			got, got2 := maxWidthsWidth(lc, tt.args.maxWidths, tt.args.addRight, tt.args.widths)
 			if !reflect.DeepEqual(got, tt.want) {
 				t.Errorf("maxWidthsWidth() = %v, want %v", got, tt.want)
 			}
